@@ -1,6 +1,8 @@
-# $Id: Simple.pm 2364 2007-11-09 11:29:56Z comdog $
+# $Id: Simple.pm 2676 2008-08-20 12:33:02Z comdog $
 package ConfigReader::Simple;
 use strict;
+use warnings;
+no warnings;
 
 use subs qw(_init_errors);
 use vars qw($VERSION $AUTOLOAD %ERROR $ERROR $Warn $Die);
@@ -10,8 +12,7 @@ use UNIVERSAL qw(isa);
 
 $Die   = '';
 $ERROR = '';
-( $VERSION ) = 1.26;
-#= sprintf "%d.%02d", q$Revision: 2364 $ =~ m/ (\d+) \. (\d+) /gx;
+( $VERSION ) = 1.27;
 $Warn = 0;
 
 our $DEBUG = 0;
@@ -757,7 +758,7 @@ sub _validate_keys
 
 		foreach $declared_key ( @$declared_keys_ref )
 			{
-			unless ( $self->{"config_data"}{$declared_key} )
+			unless ( exists $self->{"config_data"}{$declared_key} )
 				{
 				croak "Config: key '$declared_key' does not occur in file $self->{filename}\n";
       			}
